import request from '@/utils/request'

// 查询记录信息列表
export function listInfo(query) {
  return request({
    url: '/system/info/list',
    method: 'get',
    params: query
  })
}

// 查询记录信息详细
export function getInfo(id) {
  return request({
    url: '/system/info/' + id,
    method: 'get'
  })
}

// 新增记录信息
export function addInfo(data) {
  return request({
    url: '/system/info',
    method: 'post',
    data: data
  })
}

// 修改记录信息
export function updateInfo(data) {
  return request({
    url: '/system/info/put',
    method: 'post',
    data: data
  })
}

// 删除记录信息
export function delInfo(id) {
  return request({
    url: '/system/info/delete/' + id,
    method: 'get'
  })
}

// 是否同意邀请
export function delInyq(query) {
  return request({
    url: '/system/user/reply',
    method: 'get',
    params: query
  })
}
