<template>
  <div class="app-container">
    <el-form :model="queryParams" ref="queryForm" size="small" :inline="true" v-show="showSearch" label-width="78px">
     <el-row class="last">
       <p><span>搜索条件</span> <i></i></p>
        <el-col :span="6">
          <el-form-item label="标题" prop="title">
            <el-input
              style="width: 180px;"
              v-model="queryParams.title"
              placeholder="请输入标题"
              clearable
              @keyup.enter.native="handleQuery"
            />
          </el-form-item>
        </el-col>
        <el-col :span="6">
          <el-form-item label="消息类型" prop="infoType">
            <el-select style="width: 180px;" v-model="queryParams.status" placeholder="消息类型" clearable>
              <el-option
                v-for="dict in dict.type.sys_info_type"
                :key="dict.value"
                :label="dict.label"
                :value="dict.value"
              />
            </el-select>
          </el-form-item>
        </el-col>
        <el-col :span="6">
          <el-form-item label="是否已读" prop="isRead">
            <el-select style="width: 180px;" v-model="queryParams.isRead" placeholder="是否已读" clearable>
              <el-option
                v-for="dict in dict.type.sys_replacement_result"
                :key="dict.value"
                :label="dict.label"
                :value="dict.value"
              />
            </el-select>
          </el-form-item>
        </el-col>
        <el-col :span="4">
          <el-form-item>
            <el-button type="primary" icon="el-icon-search" size="mini" @click="handleQuery">搜索</el-button>
            <el-button icon="el-icon-refresh" size="mini" @click="resetQuery">重置</el-button>
          </el-form-item>
        </el-col>
      </el-row>
    </el-form>
    <div class="navde">
      <el-row :gutter="10" class="mb8" style="background-color: #fafafa ;padding-top: 0;">
        <el-col :span="24">
          <div style="display: flex; align-items: center;justify-content: space-between;">
            <p style="border-left: 5px solid #3F73FD;padding-left: 5px;"><span>信息通知</span> </p>
            <div>
          <el-button
            type="danger"
            plain
            size="mini"
            :disabled="multiple"
            @click="handleDelete"
            v-hasPermi="['system:info:remove']"
          >删除</el-button>

            </div>
          </div>
        </el-col>


        <!-- <right-toolbar :showSearch.sync="showSearch" @queryTable="getList"></right-toolbar> -->
      </el-row>


     <el-table :max-height="tableMaxHeight" v-loading="loading" :data="infoList" @selection-change="handleSelectionChange">
        <el-table-column type="selection" width="55" align="center" />
        <el-table-column label="标题" align="center" prop="title" width="120"/>
        <el-table-column label="内容" align="center" prop="content" />
        <el-table-column label="发件人姓名" align="center" prop="senderName" width="100" />
        <el-table-column label="收件人姓名" align="center" prop="addresseeName" width="100" />
        <el-table-column label="是否已读" align="center" prop="isRead" width="100">
          <template slot-scope="scope">
            <dict-tag :options="dict.type.sys_replacement_result" :value="scope.row.isRead"/>
          </template>
        </el-table-column>
        <el-table-column label="消息类型" align="center" prop="infoType" width="100">
        <template slot-scope="scope">
            <dict-tag :options="dict.type.sys_info_type" :value="scope.row.infoType"/>
          </template>
        </el-table-column>
        <el-table-column label="创建时间" align="center" prop="createTime" width="180">
          <template slot-scope="scope">
            <span>{{scope.row.createTime}}</span>
          </template>
        </el-table-column>
        <el-table-column label="操作" align="center" >
          <template slot-scope="scope">
            <el-button
            size="mini"
            type="text"
            v-if="scope.row.isRead == 0 && scope.row.infoType==1"
            @click="handleTy(scope.row)"
            >
            同意
            </el-button>
            <el-button
            size="mini"
            type="text"
            v-if="scope.row.isRead == 0 && scope.row.infoType==1"
            @click="handleJj(scope.row)"
            >
            拒绝
            </el-button>

            <el-button
              size="mini"
              type="text"
              @click="handleDelete(scope.row)"
              v-hasPermi="['system:info:remove']"
            >删除</el-button>
          </template>
        </el-table-column>
      </el-table>

      <pagination
        v-show="total>0"
        :total="total"
        :page.sync="queryParams.pageNum"
        :limit.sync="queryParams.pageSize"
        @pagination="getList"
      />
    </div>




    <!-- 添加或修改记录信息对话框 -->
    <el-dialog :title="title" :visible.sync="open" width="500px" append-to-body>
      <el-form ref="form" :model="form" :rules="rules" label-width="80px">
      </el-form>
      <div slot="footer" class="dialog-footer">
        <el-button type="primary" @click="submitForm">确 定</el-button>
        <el-button @click="cancel">取 消</el-button>
      </div>
    </el-dialog>
  </div>
</template>

<script>
import { listInfo, getInfo, delInfo, addInfo, updateInfo,  delInyq } from "@/api/kaoqin/info";

export default {
  name: "Info",
  dicts: ['sys_yes_no','sys_replacement_result','sys_info_type'],
  data() {
    return {
      // 遮罩层
      loading: true,
      // 选中数组
      ids: [],
      // 非单个禁用
      single: true,
      // 非多个禁用
      multiple: true,
      // 显示搜索条件
      showSearch: true,
      // 总条数
      total: 0,
      // 记录信息表格数据
      infoList: [],
      // 弹出层标题
      title: "",
      // 是否显示弹出层
      open: false,
      // 查询参数
      queryParams: {
        pageNum: 1,
        pageSize: 10,
        title: null,
        content: null,
        senderName: null,
        addresseeName: null,
        isRead: null,
        infoType: null,
        createTime: null,
      },
      // 表单参数
      form: {},
      // 表单校验
      rules: {
      },
      tableMaxHeight:'200'
    };
  },
  created() {
    this.getList();
    window.onresize = () => {
          this.changeTableMaxHeight()
        }
        this.changeTableMaxHeight()
  },
  methods: {
    /** 查询记录信息列表 */
    getList() {
      this.loading = true;
      listInfo(this.queryParams).then(response => {
        this.infoList = response.rows;
        this.total = response.total;
        this.loading = false;
      });
    },
    // 取消按钮
    cancel() {
      this.open = false;
      this.reset();
    },
    // 表单重置
    reset() {
      this.form = {
        id: null,
        title: null,
        content: null,
        senderId: null,
        senderName: null,
        addresseeId: null,
        addresseeName: null,
        isRead: null,
        infoType: null,
        createBy: null,
        createTime: null,
        updateBy: null,
        updateTime: null,
        remark: null
      };
      this.resetForm("form");
    },
    /** 搜索按钮操作 */
    handleQuery() {
      this.queryParams.pageNum = 1;
      this.getList();
    },
    /** 重置按钮操作 */
    resetQuery() {
      this.resetForm("queryForm");
      this.handleQuery();
    },
    // 多选框选中数据
    handleSelectionChange(selection) {
      this.ids = selection.map(item => item.id)
      this.single = selection.length!==1
      this.multiple = !selection.length
    },
    /** 新增按钮操作 */
    handleAdd() {
      this.reset();
      this.open = true;
      this.title = "添加记录信息";
    },
    /** 修改按钮操作 */
    handleUpdate(row) {
      this.reset();
      const id = row.id || this.ids
      getInfo(id).then(response => {
        this.form = response.data;
        this.open = true;
        this.title = "修改记录信息";
      });
    },
    /** 提交按钮 */
    submitForm() {
      this.$refs["form"].validate(valid => {
        if (valid) {
          if (this.form.id != null) {
            updateInfo(this.form).then(response => {
              this.$modal.msgSuccess("修改成功");
              this.open = false;
              this.getList();
            });
          } else {
            addInfo(this.form).then(response => {
              this.$modal.msgSuccess("新增成功");
              this.open = false;
              this.getList();
            });
          }
        }
      });
    },
    /** 删除按钮操作 */
    handleDelete(row) {
      const ids = row.id || this.ids;
      this.$modal.confirm('是否确认删除记录信息编号为"' + ids + '"的数据项？').then(function() {
        return delInfo(ids);
      }).then(() => {
        this.getList();
        this.$modal.msgSuccess("删除成功");
      }).catch(() => {});
    },
    /** 导出按钮操作 */
    handleExport() {
      this.download('system/info/export', {
        ...this.queryParams
      }, `info_${new Date().getTime()}.xlsx`)
    },
    // 同意
    handleTy(row){
      const ids = row.id || this.ids;
      let nhdes = {
        id:ids,
        status:2
        }
      this.$modal.confirm('此操作将同意邀请, 是否继续？').then(function() {
        return delInyq(nhdes);
      }).then(() => {
        this.getList();
        this.$modal.msgSuccess("操作成功");
      }).catch(() => {});
    },
    // 拒绝
    handleJj(row){
     const ids = row.id || this.ids;
     let nhdes = {
       id:ids,
       status:1
       }
     this.$modal.confirm('此操作将拒绝邀请, 是否继续？').then(function() {
       return delInyq(nhdes);
     }).then(() => {
       this.getList();
       this.$modal.msgSuccess("操作成功");
     }).catch(() => {});
    },
    // 获取屏幕高度
    showFilterForm () {
          this.filterActive = !this.filterActive
          this.changeTableMaxHeight()
        },

        changeTableMaxHeight () {
          let height = document.body.offsetHeight // 网页可视区域高度
          // if (this.filterActive) {
          //   this.tableMaxHeight = height - 320
          // } else {
            this.tableMaxHeight = height - 250
          // }
          console.log(height)
        }
  }
};
</script>
